from django.shortcuts import render
from django.http import HttpResponse
from django.views import View
from django.views.generic.list import ListView
from django.views.generic.detail import DetailView
from django.views.generic.edit import CreateView, UpdateView

from .models import Author, Books
from .forms import BooksForm, AuthorForm

def homepage_view(request):
    authors = Author.objects.all()
    books = Books.objects.all()
    context = {
        'authors': authors,
        'books': books
    }
    return render(request, 'bookshelf/home.html', context)

def add_book_view(request):
    if request.method == 'POST':
        form = BooksForm(request.POST)
        if form.is_valid():
            return HttpResponse('Title: {}'.format(
                title = form.cleaned_data['title'],
                author = form.cleaned_data['author'],
                year_published = form.cleaned_data['year_published'],
                ISBN = form.cleaned_data['ISBN'],
                blurb = form.cleaned_data['blurb']
                )
            )
        else:
            return render(request, 'bookshelf/add-book.html', {'form': form})
    else:
        form = BooksForm()   
    return render(request, 'bookshelf/add-book.html', {'form': form})

def add_author_view(request):
    if request.method == 'POST':
        form = AuthorForm(request.POST)
        if form.is_valid():
            return HttpResponse('Title: {}'.format(
                first_name = form.cleaned_data['first_name'],
                last_name = form.cleaned_data['last_name'],
                age = form.cleaned_data['age'],
                nationality = form.cleaned_data['nationality'],
                bio = form.cleaned_data['bio']
                )
            )
        else:
            return render(request, 'bookshelf/add-book.html', {'form': form})
    else:
        form = BooksForm()   
    return render(request, 'bookshelf/add-book.html', {'form': form})

class BooksListView(ListView):
    model = Books
    template_name = 'bookshelf/books.html'

class BooksDetailView(DetailView):
    model = Books
    template_name = 'bookshelf/book_details.html'

class BooksCreateView(CreateView):
    model = Books
    template_name = 'bookshelf/add-book.html'
    fields = '__all__'

class BooksUpdateView(UpdateView):
    model = Books
    template_name = 'bookshelf/edit-book.html'
    fields = '__all__'
    
class AuthorsListView(ListView):
    model = Author
    template_name = 'bookshelf/authors.html'

class AuthorsDetailView(DetailView):
    model = Author
    template_name = 'bookshelf/author_details.html'

class AuthorsCreateView(CreateView):
    model = Author
    template_name = 'bookshelf/add-author.html'
    fields = '__all__'

class AuthorsUpdateView(UpdateView):
    model = Author
    template_name = 'bookshelf/edit-author.html'
    fields = '__all__'
    